summaryrefslogtreecommitdiff
path: root/board/scalys/grapeboard/usb_grapeboard.c
diff options
context:
space:
mode:
Diffstat (limited to 'board/scalys/grapeboard/usb_grapeboard.c')
-rw-r--r--board/scalys/grapeboard/usb_grapeboard.c20
1 files changed, 11 insertions, 9 deletions
diff --git a/board/scalys/grapeboard/usb_grapeboard.c b/board/scalys/grapeboard/usb_grapeboard.c
index 6a2ba36..f8fbd59 100644
--- a/board/scalys/grapeboard/usb_grapeboard.c
+++ b/board/scalys/grapeboard/usb_grapeboard.c
@@ -35,7 +35,7 @@ const uint8_t hx3_settings[5 + HX3_SETTINGS_SIZE] = {
0xf0, /* cdp enabled */
0x78, /* overcurrent input is active high */
0x00, /* reserved */
- 0x00, /* USB String descriptors enabled */
+ 0x08, /* USB String descriptors enabled (0x08) / disabled (0x00) */
0x00, 0x00,
0x12, 0x00, 0x2c,
0x66, 0x66, /* USB3.0 TX driver de-emphasis */
@@ -93,14 +93,6 @@ int usb_hx3_hub_init(void) {
data += length;
}
- /* Suspend USB2.0 PHY */
- /*unsigned int val;
-
- val = in_be32(0x2f0c200);
- setbits_be32(0x2f0c200, val & (64 << 24));
- mdelay(10);*/
-
-
puts("Done!\n");
return 0;
}
@@ -109,3 +101,13 @@ int usb_hx3_hub_reset(void) {
/* USB hub cannot be reset in software without resetting the ls1012a */
return 1;
}
+
+void usb_hub_reset_devices(int port)
+{
+ /* Todo: fix issue and remove this message and temporary code added in drivers/usb/host/xhci.c at line 777*/
+ static bool warning_shown = false;
+ if (!warning_shown)
+ printf("Warning: Currently Grapeboard does not support USB 2.0 devices under U-boot until xhci hub configuration error is fixed!\n");
+ warning_shown = true;
+ return;
+}